==> kubernetes-model-1.0.29-sources.jar: annotations/io/fabric8/openshift/api/model/BuildRequestFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class BuildRequestFluentImpl<T extends BuildRequestFluent<T>> extends BaseFluent<T> implements BuildRequestFluent<T>{

     BuildRequest.ApiVersion apiVersion;     VisitableBuilder<ObjectReference, ?> from;     String kind;     Integer lastVersion;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<SourceRevision, ?> revision;     VisitableBuilder<ObjectReference, ?> triggeredByImage;     Map<String, Object> additionalProperties = new HashMap();

    public BuildRequest.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( BuildRequest.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNestedImpl<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNestedImpl<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public Integer getLastVersion(){
    return this.lastVersion;
    }
    public T withLastVersion( Integer lastVersion){
    this.lastVersion=lastVersion; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public SourceRevision getRevision(){
    return this.revision!=null?this.revision.build():null;
    }
    public T withRevision( SourceRevision revision){
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.add(this.revision);} return (T) this;
    }
    public RevisionNested<T> withNewRevision(){
    return new RevisionNestedImpl<T>();
    }
    public RevisionNested<T> withNewRevisionLike( SourceRevision item){
    return new RevisionNestedImpl<T>(item);
    }
    public RevisionNested<T> editRevision(){
    return withNewRevisionLike(getRevision());
    }
    public ObjectReference getTriggeredByImage(){
    return this.triggeredByImage!=null?this.triggeredByImage.build():null;
    }
    public T withTriggeredByImage( ObjectReference triggeredByImage){
    if (triggeredByImage!=null){ this.triggeredByImage= new ObjectReferenceBuilder(triggeredByImage); _visitables.add(this.triggeredByImage);} return (T) this;
    }
    public TriggeredByImageNested<T> withNewTriggeredByImage(){
    return new TriggeredByImageNestedImpl<T>();
    }
    public TriggeredByImageNested<T> withNewTriggeredByImageLike( ObjectReference item){
    return new TriggeredByImageNestedImpl<T>(item);
    }
    public TriggeredByImageNested<T> editTriggeredByImage(){
    return withNewTriggeredByImageLike(getTriggeredByImage());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildRequestFluentImpl that = (BuildRequestFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (lastVersion != null ? !lastVersion.equals(that.lastVersion) :that.lastVersion != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
if (triggeredByImage != null ? !triggeredByImage.equals(that.triggeredByImage) :that.triggeredByImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluentImpl.this.withFrom(builder.build());
        }
    
}
    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) BuildRequestFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class RevisionNestedImpl<N> extends SourceRevisionFluentImpl<RevisionNested<N>> implements RevisionNested<N>{

        private final SourceRevisionBuilder builder;
    
             RevisionNestedImpl ( SourceRevision item){
        this.builder = new SourceRevisionBuilder(this, item);
        }
             RevisionNestedImpl (){
        this.builder = new SourceRevisionBuilder(this);
        }
    
            public N endRevision(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluentImpl.this.withRevision(builder.build());
        }
    
}
    public class TriggeredByImageNestedImpl<N> extends ObjectReferenceFluentImpl<TriggeredByImageNested<N>> implements TriggeredByImageNested<N>{

        private final ObjectReferenceBuilder builder;
    
             TriggeredByImageNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             TriggeredByImageNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N and(){
            return (N) BuildRequestFluentImpl.this.withTriggeredByImage(builder.build());
        }
            public N endTriggeredByImage(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.32-sources.jar: annotations/io/fabric8/openshift/api/model/BuildRequestFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class BuildRequestFluentImpl<T extends BuildRequestFluent<T>> extends BaseFluent<T> implements BuildRequestFluent<T>{

     BuildRequest.ApiVersion apiVersion;     VisitableBuilder<ObjectReference, ?> from;     String kind;     Integer lastVersion;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<SourceRevision, ?> revision;     VisitableBuilder<ObjectReference, ?> triggeredByImage;     Map<String, Object> additionalProperties = new HashMap();
public BuildRequestFluentImpl(){
    
}
public BuildRequestFluentImpl( BuildRequest instance ){
    this.withApiVersion(instance.getApiVersion()); this.withFrom(instance.getFrom()); this.withKind(instance.getKind()); this.withLastVersion(instance.getLastVersion()); this.withMetadata(instance.getMetadata()); this.withRevision(instance.getRevision()); this.withTriggeredByImage(instance.getTriggeredByImage()); 
}

    public BuildRequest.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( BuildRequest.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNestedImpl<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNestedImpl<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public Integer getLastVersion(){
    return this.lastVersion;
    }
    public T withLastVersion( Integer lastVersion){
    this.lastVersion=lastVersion; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public SourceRevision getRevision(){
    return this.revision!=null?this.revision.build():null;
    }
    public T withRevision( SourceRevision revision){
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.add(this.revision);} return (T) this;
    }
    public RevisionNested<T> withNewRevision(){
    return new RevisionNestedImpl<T>();
    }
    public RevisionNested<T> withNewRevisionLike( SourceRevision item){
    return new RevisionNestedImpl<T>(item);
    }
    public RevisionNested<T> editRevision(){
    return withNewRevisionLike(getRevision());
    }
    public ObjectReference getTriggeredByImage(){
    return this.triggeredByImage!=null?this.triggeredByImage.build():null;
    }
    public T withTriggeredByImage( ObjectReference triggeredByImage){
    if (triggeredByImage!=null){ this.triggeredByImage= new ObjectReferenceBuilder(triggeredByImage); _visitables.add(this.triggeredByImage);} return (T) this;
    }
    public TriggeredByImageNested<T> withNewTriggeredByImage(){
    return new TriggeredByImageNestedImpl<T>();
    }
    public TriggeredByImageNested<T> withNewTriggeredByImageLike( ObjectReference item){
    return new TriggeredByImageNestedImpl<T>(item);
    }
    public TriggeredByImageNested<T> editTriggeredByImage(){
    return withNewTriggeredByImageLike(getTriggeredByImage());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildRequestFluentImpl that = (BuildRequestFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (lastVersion != null ? !lastVersion.equals(that.lastVersion) :that.lastVersion != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
if (triggeredByImage != null ? !triggeredByImage.equals(that.triggeredByImage) :that.triggeredByImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluentImpl.this.withFrom(builder.build());
        }
    
}
    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) BuildRequestFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class RevisionNestedImpl<N> extends SourceRevisionFluentImpl<RevisionNested<N>> implements RevisionNested<N>{

        private final SourceRevisionBuilder builder;
    
             RevisionNestedImpl (){
        this.builder = new SourceRevisionBuilder(this);
        }
             RevisionNestedImpl ( SourceRevision item){
        this.builder = new SourceRevisionBuilder(this, item);
        }
    
            public N endRevision(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluentImpl.this.withRevision(builder.build());
        }
    
}
    public class TriggeredByImageNestedImpl<N> extends ObjectReferenceFluentImpl<TriggeredByImageNested<N>> implements TriggeredByImageNested<N>{

        private final ObjectReferenceBuilder builder;
    
             TriggeredByImageNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             TriggeredByImageNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N and(){
            return (N) BuildRequestFluentImpl.this.withTriggeredByImage(builder.build());
        }
            public N endTriggeredByImage(){
            return and();
        }
    
}


}
